C*****************************************************************************
C
C_TITLE DETEST - Test performance of decompression routines.
C
C_DESCR The DETEST program tests the performance of the decompression
C       subroutines. The fortran versions of the decompression subroutines 
C       were tested using the VAX/VMS FORTRAN 77 version 4.8 compiler, and
C       Microsoft Fortran versions V3.31 and V4.01 comilers. Because
C       of differences of Fortran language compilers among different 
C       operating systems, there is no assurance that the decompression 
C       routines will correctly function on your system.  If problems occur 
C       while trying to install the decompression software on your system, 
C       this program can be run to verify the performance of the 
C       subroutines.
C
C       The DETEST program has three arrays containing fixed values.  
C       The first array, HIST, contains the values of a first-difference 
C       histogram. This array is passed to the DECMPINIT subroutine for 
C       initialization of the Huffman coding tree.  The second array, 
C       LININ, contains the values of an image-line which has been 
C       compressed. This array is passed to the DECOMPRESS subroutine
C       for decompression of the line. The output of the DECOMPRESS
C       routine is placed in the LINOUT array and is compared, sample
C       by sample, with the LINTST array.  The LINTST array contains
C       the correct values of the decompression subroutine. If there
C       is a mismatch then a failure is reported.
C
C       LINOUT, LINTST, and LININ are defined as CHARACTER*1 arrays
C       so that the elements can be treated as 8-bit bytes. 
C       
C_LIMS  This routine was tested on a VAX/VMS system, a RAINBOW PC,
C       and an IBM PC/XT system. This routine and the decompression
C       routines are totally dependent on a computer system having
C       8-bit byte addressable memory architecture.
C
C_HIST  01-July-1988 Eric Eliason, USGS Flagstaff, original verison
C****************************************************************************
      INTEGER*4 HIST(512)
      INTEGER*4 LENIN,LENOUT,ITEST,IOUT
      CHARACTER*1 LININ(227),LINTST(836),LINOUT(836)
C*****************************************************************************
C IP = logical unit number of output device
C The logical unit number points to terminal output, you may need to
C change this logical unit number for your computer system.
C******************************************************************************
      IP = 6
C****************************************************************************
C Initialize the first-difference histogram
C*****************************************************************************
      HIST(  1)=    12
      HIST(  2)=     6
      HIST(  3)=    13
      HIST(  4)=     3
      HIST(  5)=    13
      HIST(  6)=    15
      HIST(  7)=    13
      HIST(  8)=    49
      HIST(  9)=     8
      HIST( 10)=     7
      HIST( 11)=    13
      HIST( 12)=     8
      HIST( 13)=    16
      HIST( 14)=     4
      HIST( 15)=    17
      HIST( 16)=    33
      HIST( 17)=    13
      HIST( 18)=     8
      HIST( 19)=    11
      HIST( 20)=     3
      HIST( 21)=    26
      HIST( 22)=     4
      HIST( 23)=    15
      HIST( 24)=    42
      HIST( 25)=    19
      HIST( 26)=     6
      HIST( 27)=    19
      HIST( 28)=    12
      HIST( 29)=     3
      HIST( 30)=     4
      HIST( 31)=    19
      HIST( 32)=    10
      HIST( 33)=     7
      HIST( 34)=    11
      HIST( 35)=    13
      HIST( 36)=     3
      HIST( 37)=    21
      HIST( 38)=    11
      HIST( 39)=     3
      HIST( 40)=    45
      HIST( 41)=    14
      HIST( 42)=     6
      HIST( 43)=    14
      HIST( 44)=     8
      HIST( 45)=    15
      HIST( 46)=     8
      HIST( 47)=    13
      HIST( 48)=    43
      HIST( 49)=     2
      HIST( 50)=     7
      HIST( 51)=    15
      HIST( 52)=    18
      HIST( 53)=    11
      HIST( 54)=     3
      HIST( 55)=    13
      HIST( 56)=    14
      HIST( 57)=    14
      HIST( 58)=    11
      HIST( 59)=    10
      HIST( 60)=     5
      HIST( 61)=    14
      HIST( 62)=     6
      HIST( 63)=    12
      HIST( 64)=    50
      HIST( 65)=    15
      HIST( 66)=     5
      HIST( 67)=    15
      HIST( 68)=     4
      HIST( 69)=     7
      HIST( 70)=     5
      HIST( 71)=    16
      HIST( 72)=    33
      HIST( 73)=     9
      HIST( 74)=     5
      HIST( 75)=    15
      HIST( 76)=     4
      HIST( 77)=   436
      HIST( 78)=     7
      HIST( 79)=     4
      HIST( 80)=    22
      HIST( 81)=    20
      HIST( 82)=     8
      HIST( 83)=     4
      HIST( 84)=     7
      HIST( 85)=    15
      HIST( 86)=     4
      HIST( 87)=    14
      HIST( 88)=    23
      HIST( 89)=     5
      HIST( 90)=     3
      HIST( 91)=    15
      HIST( 92)=     9
      HIST( 93)=     4
      HIST( 94)=     6
      HIST( 95)=    13
      HIST( 96)=    29
      HIST( 97)=    17
      HIST( 98)=     5
      HIST( 99)=     4
      HIST(100)=     3
      HIST(101)=    16
      HIST(102)=     6
      HIST(103)=     5
      HIST(104)=    36
      HIST(105)=    32
      HIST(106)=     4
      HIST(107)=    43
      HIST(108)=     3
      HIST(109)=    39
      HIST(110)=     3
      HIST(111)=    53
      HIST(112)=    21
      HIST(113)=    32
      HIST(114)=     3
      HIST(115)=   106
      HIST(116)=     4
      HIST(117)=    78
      HIST(118)=     4
      HIST(119)=    14
      HIST(120)=    32
      HIST(121)=    18
      HIST(122)=     6
      HIST(123)=    10
      HIST(124)=     4
      HIST(125)=    24
      HIST(126)=     3
      HIST(127)=    20
      HIST(128)=    41
      HIST(129)=    14
      HIST(130)=     3
      HIST(131)=    29
      HIST(132)=     4
      HIST(133)=    17
      HIST(134)=     5
      HIST(135)=    15
      HIST(136)=    16
      HIST(137)=    17
      HIST(138)=     5
      HIST(139)=     3
      HIST(140)=     4
      HIST(141)=    17
      HIST(142)=     5
      HIST(143)=     8
      HIST(144)=    28
      HIST(145)=    13
      HIST(146)=     3
      HIST(147)=    14
      HIST(148)=     6
      HIST(149)=     7
      HIST(150)=     7
      HIST(151)=    13
      HIST(152)=    31
      HIST(153)=     6
      HIST(154)=     5
      HIST(155)=    13
      HIST(156)=     4
      HIST(157)=    19
      HIST(158)=     5
      HIST(159)=     4
      HIST(160)=    41
      HIST(161)=    14
      HIST(162)=    10
      HIST(163)=     9
      HIST(164)=     3
      HIST(165)=    14
      HIST(166)=     5
      HIST(167)=    21
      HIST(168)=    44
      HIST(169)=     8
      HIST(170)=     4
      HIST(171)=    14
      HIST(172)=    11
      HIST(173)=     7
      HIST(174)=     6
      HIST(175)=    15
      HIST(176)=     9
      HIST(177)=    20
      HIST(178)=     3
      HIST(179)=     6
      HIST(180)=     5
      HIST(181)=    22
      HIST(182)=     8
      HIST(183)=     9
      HIST(184)=    30
      HIST(185)=    22
      HIST(186)=     3
      HIST(187)=    20
      HIST(188)=    10
      HIST(189)=     3
      HIST(190)=    11
      HIST(191)=    19
      HIST(192)=    39
      HIST(193)=     2
      HIST(194)=    13
      HIST(195)=    13
      HIST(196)=     3
      HIST(197)=    27
      HIST(198)=     8
      HIST(199)=     9
      HIST(200)=    22
      HIST(201)=    16
      HIST(202)=    10
      HIST(203)=     4
      HIST(204)=    11
      HIST(205)=    14
      HIST(206)=    13
      HIST(207)=    21
      HIST(208)=    59
      HIST(209)=     3
      HIST(210)=    25
      HIST(211)=    13
      HIST(212)=    25
      HIST(213)=     8
      HIST(214)=    31
      HIST(215)=    15
      HIST(216)=    72
      HIST(217)=    26
      HIST(218)=    50
      HIST(219)=     6
      HIST(220)=    47
      HIST(221)=    14
      HIST(222)=    71
      HIST(223)=     5
      HIST(224)=   486
      HIST(225)=    17
      HIST(226)=    65
      HIST(227)=    21
      HIST(228)=    59
      HIST(229)=     8
      HIST(230)=    48
      HIST(231)=    20
      HIST(232)=    49
      HIST(233)=    17
      HIST(234)=    66
      HIST(235)=    14
      HIST(236)=    97
      HIST(237)=    20
      HIST(238)=   103
      HIST(239)=     6
      HIST(240)=   155
      HIST(241)=    35
      HIST(242)=   157
      HIST(243)=    15
      HIST(244)=   152
      HIST(245)=    17
      HIST(246)=   247
      HIST(247)=    15
      HIST(248)=   367
      HIST(249)=     8
      HIST(250)=  1147
      HIST(251)=    14
      HIST(252)=  9225
      HIST(253)=    24
      HIST(254)=113488
      HIST(255)=    23
      HIST(256)=405608
      HIST(257)=  1073
      HIST(258)=112576
      HIST(259)=   126
      HIST(260)=  9256
      HIST(261)=    86
      HIST(262)=  1179
      HIST(263)=    94
      HIST(264)=   441
      HIST(265)=   109
      HIST(266)=   347
      HIST(267)=    95
      HIST(268)=   187
      HIST(269)=    10
      HIST(270)=   183
      HIST(271)=     4
      HIST(272)=   148
      HIST(273)=    31
      HIST(274)=   192
      HIST(275)=    92
      HIST(276)=   139
      HIST(277)=    71
      HIST(278)=   298
      HIST(279)=   274
      HIST(280)=   137
      HIST(281)=    14
      HIST(282)=    43
      HIST(283)=    21
      HIST(284)=    40
      HIST(285)=   406
      HIST(286)=    40
      HIST(287)=    20
      HIST(288)=    49
      HIST(289)=    13
      HIST(290)=    67
      HIST(291)=     5
      HIST(292)=    59
      HIST(293)=    17
      HIST(294)=    79
      HIST(295)=     6
      HIST(296)=    72
      HIST(297)=    30
      HIST(298)=    54
      HIST(299)=     6
      HIST(300)=    23
      HIST(301)=    11
      HIST(302)=    19
      HIST(303)=    13
      HIST(304)=    21
      HIST(305)=    23
      HIST(306)=    14
      HIST(307)=    22
      HIST(308)=    19
      HIST(309)=     5
      HIST(310)=    24
      HIST(311)=     4
      HIST(312)=    11
      HIST(313)=    17
      HIST(314)=     6
      HIST(315)=     9
      HIST(316)=     9
      HIST(317)=    28
      HIST(318)=     4
      HIST(319)=     3
      HIST(320)=    24
      HIST(321)=    23
      HIST(322)=    34
      HIST(323)=    19
      HIST(324)=    12
      HIST(325)=     6
      HIST(326)=    10
      HIST(327)=    20
      HIST(328)=    11
      HIST(329)=    12
      HIST(330)=    31
      HIST(331)=   813
      HIST(332)=     8
      HIST(333)=    25
      HIST(334)=     5
      HIST(335)=     6
      HIST(336)=     5
      HIST(337)=    38
      HIST(338)=     9
      HIST(339)=     6
      HIST(340)=    18
      HIST(341)=     6
      HIST(342)=    13
      HIST(343)=    14
      HIST(344)=     4
      HIST(345)=    23
      HIST(346)=     9
      HIST(347)=    24
      HIST(348)=     3
      HIST(349)=    85
      HIST(350)=    94
      HIST(351)=    87
      HIST(352)=    94
      HIST(353)=    99
      HIST(354)=    90
      HIST(355)=    83
      HIST(356)=    85
      HIST(357)=   100
      HIST(358)=    85
      HIST(359)=     3
      HIST(360)=    26
      HIST(361)=     8
      HIST(362)=    22
      HIST(363)=    13
      HIST(364)=     5
      HIST(365)=    13
      HIST(366)=     7
      HIST(367)=    19
      HIST(368)=     7
      HIST(369)=    17
      HIST(370)=    14
      HIST(371)=     3
      HIST(372)=     7
      HIST(373)=    27
      HIST(374)=     6
      HIST(375)=     3
      HIST(376)=     5
      HIST(377)=    21
      HIST(378)=    12
      HIST(379)=    13
      HIST(380)=    14
      HIST(381)=     5
      HIST(382)=     7
      HIST(383)=    14
      HIST(384)=     3
      HIST(385)=    26
      HIST(386)=     7
      HIST(387)=    16
      HIST(388)=     8
      HIST(389)=     8
      HIST(390)=    18
      HIST(391)=     4
      HIST(392)=     3
      HIST(393)=    23
      HIST(394)=    16
      HIST(395)=     6
      HIST(396)=     4
      HIST(397)=    16
      HIST(398)=     5
      HIST(399)=     3
      HIST(400)=    14
      HIST(401)=     4
      HIST(402)=    19
      HIST(403)=    16
      HIST(404)=     4
      HIST(405)=     3
      HIST(406)=     3
      HIST(407)=    15
      HIST(408)=     6
      HIST(409)=    10
      HIST(410)=    21
      HIST(411)=     3
      HIST(412)=     6
      HIST(413)=    15
      HIST(414)=     4
      HIST(415)=     3
      HIST(416)=     8
      HIST(417)=    28
      HIST(418)=     6
      HIST(419)=     8
      HIST(420)=    16
      HIST(421)=     8
      HIST(422)=    10
      HIST(423)=    15
      HIST(424)=     3
      HIST(425)=    26
      HIST(426)=    24
      HIST(427)=    14
      HIST(428)=     3
      HIST(429)=     8
      HIST(430)=    17
      HIST(431)=     5
      HIST(432)=    13
      HIST(433)=    19
      HIST(434)=     3
      HIST(435)=    11
      HIST(436)=     4
      HIST(437)=    17
      HIST(438)=     5
      HIST(439)=     6
      HIST(440)=    15
      HIST(441)=    24
      HIST(442)=    20
      HIST(443)=    15
      HIST(444)=     4
      HIST(445)=     9
      HIST(446)=     4
      HIST(447)=    16
      HIST(448)=     8
      HIST(449)=     3
      HIST(450)=    28
      HIST(451)=    21
      HIST(452)=    13
      HIST(453)=    25
      HIST(454)=    11
      HIST(455)=     3
      HIST(456)=     3
      HIST(457)=    21
      HIST(458)=    17
      HIST(459)=    10
      HIST(460)=    17
      HIST(461)=     4
      HIST(462)=    11
      HIST(463)=    13
      HIST(464)=     9
      HIST(465)=    22
      HIST(466)=    17
      HIST(467)=    25
      HIST(468)=     5
      HIST(469)=    10
      HIST(470)=    24
      HIST(471)=     4
      HIST(472)=    12
      HIST(473)=    25
      HIST(474)=    18
      HIST(475)=     3
      HIST(476)=    13
      HIST(477)=    19
      HIST(478)=    11
      HIST(479)=     9
      HIST(480)=    16
      HIST(481)=     6
      HIST(482)=    34
      HIST(483)=    26
      HIST(484)=     6
      HIST(485)=     8
      HIST(486)=     6
      HIST(487)=    27
      HIST(488)=     3
      HIST(489)=    16
      HIST(490)=    13
      HIST(491)=    11
      HIST(492)=     9
      HIST(493)=    14
      HIST(494)=     5
      HIST(495)=     7
      HIST(496)=     4
      HIST(497)=    26
      HIST(498)=     8
      HIST(499)=     3
      HIST(500)=    17
      HIST(501)=     8
      HIST(502)=    12
      HIST(503)=    13
      HIST(504)=    14
      HIST(505)=     3
      HIST(506)=     3
      HIST(507)=    23
      HIST(508)=     6
      HIST(509)=     4
      HIST(510)=    12
      HIST(511)=     1
      HIST(512)=     0
C****************************************************************************
C Initialize the input compressed line, 
C****************************************************************************
      LENIN =   227
      LININ(  1) = CHAR( 28)
      LININ(  2) = CHAR(234)
      LININ(  3) = CHAR(141)
      LININ(  4) = CHAR( 54)
      LININ(  5) = CHAR( 22)
      LININ(  6) = CHAR(101)
      LININ(  7) = CHAR( 71)
      LININ(  8) = CHAR( 24)
      LININ(  9) = CHAR(198)
      LININ( 10) = CHAR(155)
      LININ( 11) = CHAR(230)
      LININ( 12) = CHAR(203)
      LININ( 13) = CHAR(113)
      LININ( 14) = CHAR( 56)
      LININ( 15) = CHAR(160)
      LININ( 16) = CHAR( 31)
      LININ( 17) = CHAR( 30)
      LININ( 18) = CHAR( 50)
      LININ( 19) = CHAR(193)
      LININ( 20) = CHAR(142)
      LININ( 21) = CHAR(151)
      LININ( 22) = CHAR( 45)
      LININ( 23) = CHAR(167)
      LININ( 24) = CHAR( 30)
      LININ( 25) = CHAR(210)
      LININ( 26) = CHAR(218)
      LININ( 27) = CHAR( 92)
      LININ( 28) = CHAR( 82)
      LININ( 29) = CHAR( 84)
      LININ( 30) = CHAR(150)
      LININ( 31) = CHAR( 51)
      LININ( 32) = CHAR( 99)
      LININ( 33) = CHAR(203)
      LININ( 34) = CHAR(250)
      LININ( 35) = CHAR( 25)
      LININ( 36) = CHAR(108)
      LININ( 37) = CHAR( 33)
      LININ( 38) = CHAR(151)
      LININ( 39) = CHAR(149)
      LININ( 40) = CHAR(248)
      LININ( 41) = CHAR( 73)
      LININ( 42) = CHAR(105)
      LININ( 43) = CHAR(114)
      LININ( 44) = CHAR(198)
      LININ( 45) = CHAR(206)
      LININ( 46) = CHAR(151)
      LININ( 47) = CHAR(113)
      LININ( 48) = CHAR(180)
      LININ( 49) = CHAR(143)
      LININ( 50) = CHAR(216)
      LININ( 51) = CHAR(207)
      LININ( 52) = CHAR(142)
      LININ( 53) = CHAR(231)
      LININ( 54) = CHAR( 55)
      LININ( 55) = CHAR(255)
      LININ( 56) = CHAR(105)
      LININ( 57) = CHAR(108)
      LININ( 58) = CHAR(199)
      LININ( 59) = CHAR(203)
      LININ( 60) = CHAR(143)
      LININ( 61) = CHAR(226)
      LININ( 62) = CHAR(162)
      LININ( 63) = CHAR(150)
      LININ( 64) = CHAR( 95)
      LININ( 65) = CHAR(151)
      LININ( 66) = CHAR(184)
      LININ( 67) = CHAR(207)
      LININ( 68) = CHAR(113)
      LININ( 69) = CHAR(205)
      LININ( 70) = CHAR(149)
      LININ( 71) = CHAR( 38)
      LININ( 72) = CHAR(205)
      LININ( 73) = CHAR(150)
      LININ( 74) = CHAR( 89)
      LININ( 75) = CHAR( 82)
      LININ( 76) = CHAR( 88)
      LININ( 77) = CHAR(160)
      LININ( 78) = CHAR(216)
      LININ( 79) = CHAR(231)
      LININ( 80) = CHAR(184)
      LININ( 81) = CHAR(210)
      LININ( 82) = CHAR(247)
      LININ( 83) = CHAR(255)
      LININ( 84) = CHAR( 96)
      LININ( 85) = CHAR(163)
      LININ( 86) = CHAR( 47)
      LININ( 87) = CHAR( 82)
      LININ( 88) = CHAR(108)
      LININ( 89) = CHAR(102)
      LININ( 90) = CHAR(193)
      LININ( 91) = CHAR( 67)
      LININ( 92) = CHAR(130)
      LININ( 93) = CHAR(139)
      LININ( 94) = CHAR(143)
      LININ( 95) = CHAR( 47)
      LININ( 96) = CHAR(207)
      LININ( 97) = CHAR(221)
      LININ( 98) = CHAR(165)
      LININ( 99) = CHAR(199)
      LININ(100) = CHAR( 30)
      LININ(101) = CHAR( 94)
      LININ(102) = CHAR(201)
      LININ(103) = CHAR(113)
      LININ(104) = CHAR(180)
      LININ(105) = CHAR(238)
      LININ(106) = CHAR( 42)
      LININ(107) = CHAR( 71)
      LININ(108) = CHAR(101)
      LININ(109) = CHAR(145)
      LININ(110) = CHAR(218)
      LININ(111) = CHAR( 95)
      LININ(112) = CHAR(188)
      LININ(113) = CHAR(220)
      LININ(114) = CHAR( 31)
      LININ(115) = CHAR( 84)
      LININ(116) = CHAR( 46)
      LININ(117) = CHAR(109)
      LININ(118) = CHAR( 47)
      LININ(119) = CHAR(234)
      LININ(120) = CHAR(165)
      LININ(121) = CHAR(138)
      LININ(122) = CHAR( 77)
      LININ(123) = CHAR(246)
      LININ(124) = CHAR(148)
      LININ(125) = CHAR(208)
      LININ(126) = CHAR(203)
      LININ(127) = CHAR( 42)
      LININ(128) = CHAR( 42)
      LININ(129) = CHAR( 78)
      LININ(130) = CHAR(226)
      LININ(131) = CHAR(129)
      LININ(132) = CHAR(218)
      LININ(133) = CHAR( 93)
      LININ(134) = CHAR(165)
      LININ(135) = CHAR(199)
      LININ(136) = CHAR(105)
      LININ(137) = CHAR(168)
      LININ(138) = CHAR(101)
      LININ(139) = CHAR( 73)
      LININ(140) = CHAR(227)
      LININ(141) = CHAR(248)
      LININ(142) = CHAR(161)
      LININ(143) = CHAR(166)
      LININ(144) = CHAR(210)
      LININ(145) = CHAR(161)
      LININ(146) = CHAR( 67)
      LININ(147) = CHAR(142)
      LININ(148) = CHAR(149)
      LININ(149) = CHAR(118)
      LININ(150) = CHAR( 70)
      LININ(151) = CHAR(151)
      LININ(152) = CHAR( 20)
      LININ(153) = CHAR( 11)
      LININ(154) = CHAR( 73)
      LININ(155) = CHAR( 99)
      LININ(156) = CHAR( 31)
      LININ(157) = CHAR( 26)
      LININ(158) = CHAR( 91)
      LININ(159) = CHAR( 96)
      LININ(160) = CHAR(198)
      LININ(161) = CHAR( 90)
      LININ(162) = CHAR( 92)
      LININ(163) = CHAR( 83)
      LININ(164) = CHAR( 75)
      LININ(165) = CHAR(246)
      LININ(166) = CHAR( 88)
      LININ(167) = CHAR( 54)
      LININ(168) = CHAR( 22)
      LININ(169) = CHAR(210)
      LININ(170) = CHAR(199)
      LININ(171) = CHAR(216)
      LININ(172) = CHAR(198)
      LININ(173) = CHAR(118)
      LININ(174) = CHAR(118)
      LININ(175) = CHAR(113)
      LININ(176) = CHAR(140)
      LININ(177) = CHAR(108)
      LININ(178) = CHAR(216)
      LININ(179) = CHAR( 63)
      LININ(180) = CHAR(101)
      LININ(181) = CHAR(162)
      LININ(182) = CHAR(205)
      LININ(183) = CHAR( 12)
      LININ(184) = CHAR(110)
      LININ(185) = CHAR(184)
      LININ(186) = CHAR(127)
      LININ(187) = CHAR(255)
      LININ(188) = CHAR(255)
      LININ(189) = CHAR(255)
      LININ(190) = CHAR(255)
      LININ(191) = CHAR(255)
      LININ(192) = CHAR(255)
      LININ(193) = CHAR(255)
      LININ(194) = CHAR(255)
      LININ(195) = CHAR(255)
      LININ(196) = CHAR(255)
      LININ(197) = CHAR(255)
      LININ(198) = CHAR(255)
      LININ(199) = CHAR(255)
      LININ(200) = CHAR(255)
      LININ(201) = CHAR(255)
      LININ(202) = CHAR(255)
      LININ(203) = CHAR(255)
      LININ(204) = CHAR(255)
      LININ(205) = CHAR(254)
      LININ(206) = CHAR(133)
      LININ(207) = CHAR( 64)
      LININ(208) = CHAR( 93)
      LININ(209) = CHAR( 22)
      LININ(210) = CHAR(188)
      LININ(211) = CHAR( 82)
      LININ(212) = CHAR( 58)
      LININ(213) = CHAR(241)
      LININ(214) = CHAR( 72)
      LININ(215) = CHAR(250)
      LININ(216) = CHAR(252)
      LININ(217) = CHAR(148)
      LININ(218) = CHAR(176)
      LININ(219) = CHAR(255)
      LININ(220) = CHAR(255)
      LININ(221) = CHAR(241)
      LININ(222) = CHAR( 29)
      LININ(223) = CHAR( 29)
      LININ(224) = CHAR(124)
      LININ(225) = CHAR(100)
      LININ(226) = CHAR( 27)
      LININ(227) = CHAR(128)
C******************************************************************************
C Initialize the result of the decompressed line. This array is tested
C against the result of the DECOMPRESS subroutine
C******************************************************************************
      LENOUT =   836
      LINTST(  1) = CHAR( 28)
      LINTST(  2) = CHAR( 28)
      LINTST(  3) = CHAR( 28)
      LINTST(  4) = CHAR( 28)
      LINTST(  5) = CHAR( 24)
      LINTST(  6) = CHAR( 24)
      LINTST(  7) = CHAR( 26)
      LINTST(  8) = CHAR( 24)
      LINTST(  9) = CHAR( 28)
      LINTST( 10) = CHAR( 28)
      LINTST( 11) = CHAR( 26)
      LINTST( 12) = CHAR( 28)
      LINTST( 13) = CHAR( 30)
      LINTST( 14) = CHAR( 30)
      LINTST( 15) = CHAR( 28)
      LINTST( 16) = CHAR( 30)
      LINTST( 17) = CHAR( 30)
      LINTST( 18) = CHAR( 30)
      LINTST( 19) = CHAR( 32)
      LINTST( 20) = CHAR( 32)
      LINTST( 21) = CHAR( 28)
      LINTST( 22) = CHAR( 30)
      LINTST( 23) = CHAR( 30)
      LINTST( 24) = CHAR( 30)
      LINTST( 25) = CHAR( 30)
      LINTST( 26) = CHAR( 32)
      LINTST( 27) = CHAR( 30)
      LINTST( 28) = CHAR( 32)
      LINTST( 29) = CHAR( 30)
      LINTST( 30) = CHAR( 32)
      LINTST( 31) = CHAR( 30)
      LINTST( 32) = CHAR( 34)
      LINTST( 33) = CHAR( 34)
      LINTST( 34) = CHAR( 32)
      LINTST( 35) = CHAR( 32)
      LINTST( 36) = CHAR( 32)
      LINTST( 37) = CHAR( 32)
      LINTST( 38) = CHAR( 34)
      LINTST( 39) = CHAR( 34)
      LINTST( 40) = CHAR( 34)
      LINTST( 41) = CHAR( 32)
      LINTST( 42) = CHAR( 34)
      LINTST( 43) = CHAR( 34)
      LINTST( 44) = CHAR( 32)
      LINTST( 45) = CHAR( 30)
      LINTST( 46) = CHAR( 30)
      LINTST( 47) = CHAR( 32)
      LINTST( 48) = CHAR( 36)
      LINTST( 49) = CHAR( 36)
      LINTST( 50) = CHAR( 36)
      LINTST( 51) = CHAR( 38)
      LINTST( 52) = CHAR( 34)
      LINTST( 53) = CHAR( 36)
      LINTST( 54) = CHAR( 38)
      LINTST( 55) = CHAR( 40)
      LINTST( 56) = CHAR( 38)
      LINTST( 57) = CHAR( 38)
      LINTST( 58) = CHAR( 38)
      LINTST( 59) = CHAR( 38)
      LINTST( 60) = CHAR( 40)
      LINTST( 61) = CHAR( 38)
      LINTST( 62) = CHAR( 38)
      LINTST( 63) = CHAR( 38)
      LINTST( 64) = CHAR( 40)
      LINTST( 65) = CHAR( 38)
      LINTST( 66) = CHAR( 40)
      LINTST( 67) = CHAR( 40)
      LINTST( 68) = CHAR( 38)
      LINTST( 69) = CHAR( 40)
      LINTST( 70) = CHAR( 42)
      LINTST( 71) = CHAR( 40)
      LINTST( 72) = CHAR( 42)
      LINTST( 73) = CHAR( 40)
      LINTST( 74) = CHAR( 40)
      LINTST( 75) = CHAR( 44)
      LINTST( 76) = CHAR( 42)
      LINTST( 77) = CHAR( 42)
      LINTST( 78) = CHAR( 44)
      LINTST( 79) = CHAR( 44)
      LINTST( 80) = CHAR( 42)
      LINTST( 81) = CHAR( 40)
      LINTST( 82) = CHAR( 44)
      LINTST( 83) = CHAR( 44)
      LINTST( 84) = CHAR( 44)
      LINTST( 85) = CHAR( 46)
      LINTST( 86) = CHAR( 44)
      LINTST( 87) = CHAR( 44)
      LINTST( 88) = CHAR( 44)
      LINTST( 89) = CHAR( 42)
      LINTST( 90) = CHAR( 46)
      LINTST( 91) = CHAR( 44)
      LINTST( 92) = CHAR( 42)
      LINTST( 93) = CHAR( 46)
      LINTST( 94) = CHAR( 44)
      LINTST( 95) = CHAR( 44)
      LINTST( 96) = CHAR( 46)
      LINTST( 97) = CHAR( 42)
      LINTST( 98) = CHAR( 46)
      LINTST( 99) = CHAR( 42)
      LINTST(100) = CHAR( 46)
      LINTST(101) = CHAR( 44)
      LINTST(102) = CHAR( 46)
      LINTST(103) = CHAR( 44)
      LINTST(104) = CHAR( 46)
      LINTST(105) = CHAR( 46)
      LINTST(106) = CHAR( 46)
      LINTST(107) = CHAR( 44)
      LINTST(108) = CHAR( 46)
      LINTST(109) = CHAR( 44)
      LINTST(110) = CHAR( 44)
      LINTST(111) = CHAR( 44)
      LINTST(112) = CHAR( 46)
      LINTST(113) = CHAR( 46)
      LINTST(114) = CHAR( 44)
      LINTST(115) = CHAR( 44)
      LINTST(116) = CHAR( 44)
      LINTST(117) = CHAR( 44)
      LINTST(118) = CHAR( 44)
      LINTST(119) = CHAR( 44)
      LINTST(120) = CHAR( 36)
      LINTST(121) = CHAR( 20)
      LINTST(122) = CHAR( 12)
      LINTST(123) = CHAR( 20)
      LINTST(124) = CHAR( 40)
      LINTST(125) = CHAR( 44)
      LINTST(126) = CHAR( 46)
      LINTST(127) = CHAR( 46)
      LINTST(128) = CHAR( 44)
      LINTST(129) = CHAR( 48)
      LINTST(130) = CHAR( 46)
      LINTST(131) = CHAR( 46)
      LINTST(132) = CHAR( 48)
      LINTST(133) = CHAR( 48)
      LINTST(134) = CHAR( 46)
      LINTST(135) = CHAR( 48)
      LINTST(136) = CHAR( 46)
      LINTST(137) = CHAR( 44)
      LINTST(138) = CHAR( 46)
      LINTST(139) = CHAR( 46)
      LINTST(140) = CHAR( 46)
      LINTST(141) = CHAR( 46)
      LINTST(142) = CHAR( 50)
      LINTST(143) = CHAR( 48)
      LINTST(144) = CHAR( 48)
      LINTST(145) = CHAR( 46)
      LINTST(146) = CHAR( 46)
      LINTST(147) = CHAR( 48)
      LINTST(148) = CHAR( 46)
      LINTST(149) = CHAR( 44)
      LINTST(150) = CHAR( 48)
      LINTST(151) = CHAR( 50)
      LINTST(152) = CHAR( 48)
      LINTST(153) = CHAR( 48)
      LINTST(154) = CHAR( 48)
      LINTST(155) = CHAR( 48)
      LINTST(156) = CHAR( 48)
      LINTST(157) = CHAR( 46)
      LINTST(158) = CHAR( 48)
      LINTST(159) = CHAR( 46)
      LINTST(160) = CHAR( 48)
      LINTST(161) = CHAR( 48)
      LINTST(162) = CHAR( 48)
      LINTST(163) = CHAR( 48)
      LINTST(164) = CHAR( 48)
      LINTST(165) = CHAR( 48)
      LINTST(166) = CHAR( 50)
      LINTST(167) = CHAR( 48)
      LINTST(168) = CHAR( 48)
      LINTST(169) = CHAR( 46)
      LINTST(170) = CHAR( 46)
      LINTST(171) = CHAR( 48)
      LINTST(172) = CHAR( 48)
      LINTST(173) = CHAR( 48)
      LINTST(174) = CHAR( 48)
      LINTST(175) = CHAR( 50)
      LINTST(176) = CHAR( 50)
      LINTST(177) = CHAR( 50)
      LINTST(178) = CHAR( 48)
      LINTST(179) = CHAR( 48)
      LINTST(180) = CHAR( 48)
      LINTST(181) = CHAR( 48)
      LINTST(182) = CHAR( 48)
      LINTST(183) = CHAR( 48)
      LINTST(184) = CHAR( 48)
      LINTST(185) = CHAR( 48)
      LINTST(186) = CHAR( 48)
      LINTST(187) = CHAR( 48)
      LINTST(188) = CHAR( 46)
      LINTST(189) = CHAR( 50)
      LINTST(190) = CHAR( 48)
      LINTST(191) = CHAR( 46)
      LINTST(192) = CHAR( 48)
      LINTST(193) = CHAR( 48)
      LINTST(194) = CHAR( 48)
      LINTST(195) = CHAR( 50)
      LINTST(196) = CHAR( 48)
      LINTST(197) = CHAR( 48)
      LINTST(198) = CHAR( 48)
      LINTST(199) = CHAR( 48)
      LINTST(200) = CHAR( 50)
      LINTST(201) = CHAR( 50)
      LINTST(202) = CHAR( 48)
      LINTST(203) = CHAR( 48)
      LINTST(204) = CHAR( 50)
      LINTST(205) = CHAR( 48)
      LINTST(206) = CHAR( 48)
      LINTST(207) = CHAR( 48)
      LINTST(208) = CHAR( 48)
      LINTST(209) = CHAR( 48)
      LINTST(210) = CHAR( 48)
      LINTST(211) = CHAR( 50)
      LINTST(212) = CHAR( 46)
      LINTST(213) = CHAR( 46)
      LINTST(214) = CHAR( 48)
      LINTST(215) = CHAR( 44)
      LINTST(216) = CHAR( 50)
      LINTST(217) = CHAR( 48)
      LINTST(218) = CHAR( 48)
      LINTST(219) = CHAR( 48)
      LINTST(220) = CHAR( 48)
      LINTST(221) = CHAR( 48)
      LINTST(222) = CHAR( 50)
      LINTST(223) = CHAR( 50)
      LINTST(224) = CHAR( 48)
      LINTST(225) = CHAR( 48)
      LINTST(226) = CHAR( 48)
      LINTST(227) = CHAR( 46)
      LINTST(228) = CHAR( 46)
      LINTST(229) = CHAR( 48)
      LINTST(230) = CHAR( 46)
      LINTST(231) = CHAR( 48)
      LINTST(232) = CHAR( 48)
      LINTST(233) = CHAR( 48)
      LINTST(234) = CHAR( 48)
      LINTST(235) = CHAR( 48)
      LINTST(236) = CHAR( 46)
      LINTST(237) = CHAR( 46)
      LINTST(238) = CHAR( 48)
      LINTST(239) = CHAR( 46)
      LINTST(240) = CHAR( 46)
      LINTST(241) = CHAR( 48)
      LINTST(242) = CHAR( 48)
      LINTST(243) = CHAR( 48)
      LINTST(244) = CHAR( 46)
      LINTST(245) = CHAR( 48)
      LINTST(246) = CHAR( 48)
      LINTST(247) = CHAR( 44)
      LINTST(248) = CHAR( 48)
      LINTST(249) = CHAR( 48)
      LINTST(250) = CHAR( 46)
      LINTST(251) = CHAR( 48)
      LINTST(252) = CHAR( 48)
      LINTST(253) = CHAR( 48)
      LINTST(254) = CHAR( 46)
      LINTST(255) = CHAR( 48)
      LINTST(256) = CHAR( 48)
      LINTST(257) = CHAR( 46)
      LINTST(258) = CHAR( 48)
      LINTST(259) = CHAR( 48)
      LINTST(260) = CHAR( 46)
      LINTST(261) = CHAR( 48)
      LINTST(262) = CHAR( 48)
      LINTST(263) = CHAR( 44)
      LINTST(264) = CHAR( 48)
      LINTST(265) = CHAR( 46)
      LINTST(266) = CHAR( 48)
      LINTST(267) = CHAR( 44)
      LINTST(268) = CHAR( 46)
      LINTST(269) = CHAR( 48)
      LINTST(270) = CHAR( 48)
      LINTST(271) = CHAR( 48)
      LINTST(272) = CHAR( 46)
      LINTST(273) = CHAR( 48)
      LINTST(274) = CHAR( 46)
      LINTST(275) = CHAR( 46)
      LINTST(276) = CHAR( 48)
      LINTST(277) = CHAR( 48)
      LINTST(278) = CHAR( 48)
      LINTST(279) = CHAR( 48)
      LINTST(280) = CHAR( 48)
      LINTST(281) = CHAR( 46)
      LINTST(282) = CHAR( 46)
      LINTST(283) = CHAR( 48)
      LINTST(284) = CHAR( 46)
      LINTST(285) = CHAR( 50)
      LINTST(286) = CHAR( 48)
      LINTST(287) = CHAR( 48)
      LINTST(288) = CHAR( 48)
      LINTST(289) = CHAR( 46)
      LINTST(290) = CHAR( 46)
      LINTST(291) = CHAR( 46)
      LINTST(292) = CHAR( 46)
      LINTST(293) = CHAR( 46)
      LINTST(294) = CHAR( 46)
      LINTST(295) = CHAR( 46)
      LINTST(296) = CHAR( 46)
      LINTST(297) = CHAR( 46)
      LINTST(298) = CHAR( 46)
      LINTST(299) = CHAR( 44)
      LINTST(300) = CHAR( 46)
      LINTST(301) = CHAR( 48)
      LINTST(302) = CHAR( 44)
      LINTST(303) = CHAR( 46)
      LINTST(304) = CHAR( 46)
      LINTST(305) = CHAR( 46)
      LINTST(306) = CHAR( 48)
      LINTST(307) = CHAR( 48)
      LINTST(308) = CHAR( 46)
      LINTST(309) = CHAR( 46)
      LINTST(310) = CHAR( 46)
      LINTST(311) = CHAR( 42)
      LINTST(312) = CHAR( 46)
      LINTST(313) = CHAR( 46)
      LINTST(314) = CHAR( 44)
      LINTST(315) = CHAR( 46)
      LINTST(316) = CHAR( 44)
      LINTST(317) = CHAR( 46)
      LINTST(318) = CHAR( 46)
      LINTST(319) = CHAR( 46)
      LINTST(320) = CHAR( 44)
      LINTST(321) = CHAR( 46)
      LINTST(322) = CHAR( 48)
      LINTST(323) = CHAR( 44)
      LINTST(324) = CHAR( 46)
      LINTST(325) = CHAR( 44)
      LINTST(326) = CHAR( 44)
      LINTST(327) = CHAR( 46)
      LINTST(328) = CHAR( 48)
      LINTST(329) = CHAR( 44)
      LINTST(330) = CHAR( 46)
      LINTST(331) = CHAR( 46)
      LINTST(332) = CHAR( 44)
      LINTST(333) = CHAR( 44)
      LINTST(334) = CHAR( 46)
      LINTST(335) = CHAR( 44)
      LINTST(336) = CHAR( 44)
      LINTST(337) = CHAR( 44)
      LINTST(338) = CHAR( 46)
      LINTST(339) = CHAR( 46)
      LINTST(340) = CHAR( 44)
      LINTST(341) = CHAR( 44)
      LINTST(342) = CHAR( 44)
      LINTST(343) = CHAR( 44)
      LINTST(344) = CHAR( 44)
      LINTST(345) = CHAR( 46)
      LINTST(346) = CHAR( 46)
      LINTST(347) = CHAR( 46)
      LINTST(348) = CHAR( 46)
      LINTST(349) = CHAR( 46)
      LINTST(350) = CHAR( 46)
      LINTST(351) = CHAR( 46)
      LINTST(352) = CHAR( 44)
      LINTST(353) = CHAR( 44)
      LINTST(354) = CHAR( 42)
      LINTST(355) = CHAR( 46)
      LINTST(356) = CHAR( 44)
      LINTST(357) = CHAR( 44)
      LINTST(358) = CHAR( 46)
      LINTST(359) = CHAR( 44)
      LINTST(360) = CHAR( 44)
      LINTST(361) = CHAR( 46)
      LINTST(362) = CHAR( 44)
      LINTST(363) = CHAR( 44)
      LINTST(364) = CHAR( 44)
      LINTST(365) = CHAR( 46)
      LINTST(366) = CHAR( 46)
      LINTST(367) = CHAR( 44)
      LINTST(368) = CHAR( 44)
      LINTST(369) = CHAR( 44)
      LINTST(370) = CHAR( 42)
      LINTST(371) = CHAR( 44)
      LINTST(372) = CHAR( 44)
      LINTST(373) = CHAR( 46)
      LINTST(374) = CHAR( 46)
      LINTST(375) = CHAR( 44)
      LINTST(376) = CHAR( 44)
      LINTST(377) = CHAR( 46)
      LINTST(378) = CHAR( 44)
      LINTST(379) = CHAR( 42)
      LINTST(380) = CHAR( 46)
      LINTST(381) = CHAR( 46)
      LINTST(382) = CHAR( 46)
      LINTST(383) = CHAR( 44)
      LINTST(384) = CHAR( 44)
      LINTST(385) = CHAR( 46)
      LINTST(386) = CHAR( 42)
      LINTST(387) = CHAR( 42)
      LINTST(388) = CHAR( 44)
      LINTST(389) = CHAR( 44)
      LINTST(390) = CHAR( 46)
      LINTST(391) = CHAR( 44)
      LINTST(392) = CHAR( 44)
      LINTST(393) = CHAR( 42)
      LINTST(394) = CHAR( 44)
      LINTST(395) = CHAR( 44)
      LINTST(396) = CHAR( 42)
      LINTST(397) = CHAR( 44)
      LINTST(398) = CHAR( 44)
      LINTST(399) = CHAR( 46)
      LINTST(400) = CHAR( 44)
      LINTST(401) = CHAR( 44)
      LINTST(402) = CHAR( 42)
      LINTST(403) = CHAR( 46)
      LINTST(404) = CHAR( 44)
      LINTST(405) = CHAR( 44)
      LINTST(406) = CHAR( 44)
      LINTST(407) = CHAR( 44)
      LINTST(408) = CHAR( 44)
      LINTST(409) = CHAR( 42)
      LINTST(410) = CHAR( 42)
      LINTST(411) = CHAR( 42)
      LINTST(412) = CHAR( 44)
      LINTST(413) = CHAR( 44)
      LINTST(414) = CHAR( 44)
      LINTST(415) = CHAR( 42)
      LINTST(416) = CHAR( 42)
      LINTST(417) = CHAR( 44)
      LINTST(418) = CHAR( 46)
      LINTST(419) = CHAR( 44)
      LINTST(420) = CHAR( 44)
      LINTST(421) = CHAR( 44)
      LINTST(422) = CHAR( 44)
      LINTST(423) = CHAR( 40)
      LINTST(424) = CHAR( 40)
      LINTST(425) = CHAR( 42)
      LINTST(426) = CHAR( 44)
      LINTST(427) = CHAR( 44)
      LINTST(428) = CHAR( 42)
      LINTST(429) = CHAR( 42)
      LINTST(430) = CHAR( 44)
      LINTST(431) = CHAR( 44)
      LINTST(432) = CHAR( 44)
      LINTST(433) = CHAR( 42)
      LINTST(434) = CHAR( 46)
      LINTST(435) = CHAR( 44)
      LINTST(436) = CHAR( 44)
      LINTST(437) = CHAR( 44)
      LINTST(438) = CHAR( 44)
      LINTST(439) = CHAR( 44)
      LINTST(440) = CHAR( 44)
      LINTST(441) = CHAR( 40)
      LINTST(442) = CHAR( 40)
      LINTST(443) = CHAR( 44)
      LINTST(444) = CHAR( 42)
      LINTST(445) = CHAR( 44)
      LINTST(446) = CHAR( 40)
      LINTST(447) = CHAR( 44)
      LINTST(448) = CHAR( 44)
      LINTST(449) = CHAR( 42)
      LINTST(450) = CHAR( 42)
      LINTST(451) = CHAR( 42)
      LINTST(452) = CHAR( 42)
      LINTST(453) = CHAR( 40)
      LINTST(454) = CHAR( 44)
      LINTST(455) = CHAR( 48)
      LINTST(456) = CHAR( 48)
      LINTST(457) = CHAR( 40)
      LINTST(458) = CHAR( 46)
      LINTST(459) = CHAR( 42)
      LINTST(460) = CHAR( 44)
      LINTST(461) = CHAR( 44)
      LINTST(462) = CHAR( 40)
      LINTST(463) = CHAR( 44)
      LINTST(464) = CHAR( 44)
      LINTST(465) = CHAR( 44)
      LINTST(466) = CHAR( 42)
      LINTST(467) = CHAR( 42)
      LINTST(468) = CHAR( 44)
      LINTST(469) = CHAR( 40)
      LINTST(470) = CHAR( 42)
      LINTST(471) = CHAR( 44)
      LINTST(472) = CHAR( 42)
      LINTST(473) = CHAR( 42)
      LINTST(474) = CHAR( 40)
      LINTST(475) = CHAR( 44)
      LINTST(476) = CHAR( 42)
      LINTST(477) = CHAR( 42)
      LINTST(478) = CHAR( 40)
      LINTST(479) = CHAR( 44)
      LINTST(480) = CHAR( 42)
      LINTST(481) = CHAR( 42)
      LINTST(482) = CHAR( 44)
      LINTST(483) = CHAR( 42)
      LINTST(484) = CHAR( 42)
      LINTST(485) = CHAR( 40)
      LINTST(486) = CHAR( 44)
      LINTST(487) = CHAR( 44)
      LINTST(488) = CHAR( 40)
      LINTST(489) = CHAR( 42)
      LINTST(490) = CHAR( 40)
      LINTST(491) = CHAR( 42)
      LINTST(492) = CHAR( 42)
      LINTST(493) = CHAR( 38)
      LINTST(494) = CHAR( 42)
      LINTST(495) = CHAR( 42)
      LINTST(496) = CHAR( 42)
      LINTST(497) = CHAR( 42)
      LINTST(498) = CHAR( 44)
      LINTST(499) = CHAR( 42)
      LINTST(500) = CHAR( 42)
      LINTST(501) = CHAR( 42)
      LINTST(502) = CHAR( 42)
      LINTST(503) = CHAR( 42)
      LINTST(504) = CHAR( 42)
      LINTST(505) = CHAR( 44)
      LINTST(506) = CHAR( 40)
      LINTST(507) = CHAR( 42)
      LINTST(508) = CHAR( 40)
      LINTST(509) = CHAR( 44)
      LINTST(510) = CHAR( 44)
      LINTST(511) = CHAR( 42)
      LINTST(512) = CHAR( 46)
      LINTST(513) = CHAR( 42)
      LINTST(514) = CHAR( 44)
      LINTST(515) = CHAR( 40)
      LINTST(516) = CHAR( 42)
      LINTST(517) = CHAR( 40)
      LINTST(518) = CHAR( 40)
      LINTST(519) = CHAR( 42)
      LINTST(520) = CHAR( 40)
      LINTST(521) = CHAR( 40)
      LINTST(522) = CHAR( 44)
      LINTST(523) = CHAR( 40)
      LINTST(524) = CHAR( 40)
      LINTST(525) = CHAR( 40)
      LINTST(526) = CHAR( 40)
      LINTST(527) = CHAR( 38)
      LINTST(528) = CHAR( 40)
      LINTST(529) = CHAR( 40)
      LINTST(530) = CHAR( 42)
      LINTST(531) = CHAR( 40)
      LINTST(532) = CHAR( 44)
      LINTST(533) = CHAR( 42)
      LINTST(534) = CHAR( 42)
      LINTST(535) = CHAR( 44)
      LINTST(536) = CHAR( 40)
      LINTST(537) = CHAR( 42)
      LINTST(538) = CHAR( 44)
      LINTST(539) = CHAR( 38)
      LINTST(540) = CHAR( 42)
      LINTST(541) = CHAR( 40)
      LINTST(542) = CHAR( 42)
      LINTST(543) = CHAR( 40)
      LINTST(544) = CHAR( 42)
      LINTST(545) = CHAR( 40)
      LINTST(546) = CHAR( 40)
      LINTST(547) = CHAR( 40)
      LINTST(548) = CHAR( 40)
      LINTST(549) = CHAR( 42)
      LINTST(550) = CHAR( 40)
      LINTST(551) = CHAR( 44)
      LINTST(552) = CHAR( 42)
      LINTST(553) = CHAR( 40)
      LINTST(554) = CHAR( 38)
      LINTST(555) = CHAR( 40)
      LINTST(556) = CHAR( 42)
      LINTST(557) = CHAR( 40)
      LINTST(558) = CHAR( 42)
      LINTST(559) = CHAR( 40)
      LINTST(560) = CHAR( 42)
      LINTST(561) = CHAR( 42)
      LINTST(562) = CHAR( 40)
      LINTST(563) = CHAR( 44)
      LINTST(564) = CHAR( 42)
      LINTST(565) = CHAR( 42)
      LINTST(566) = CHAR( 44)
      LINTST(567) = CHAR( 40)
      LINTST(568) = CHAR( 38)
      LINTST(569) = CHAR( 42)
      LINTST(570) = CHAR( 40)
      LINTST(571) = CHAR( 40)
      LINTST(572) = CHAR( 40)
      LINTST(573) = CHAR( 40)
      LINTST(574) = CHAR( 40)
      LINTST(575) = CHAR( 38)
      LINTST(576) = CHAR( 40)
      LINTST(577) = CHAR( 40)
      LINTST(578) = CHAR( 38)
      LINTST(579) = CHAR( 40)
      LINTST(580) = CHAR( 42)
      LINTST(581) = CHAR( 40)
      LINTST(582) = CHAR( 38)
      LINTST(583) = CHAR( 40)
      LINTST(584) = CHAR( 42)
      LINTST(585) = CHAR( 42)
      LINTST(586) = CHAR( 40)
      LINTST(587) = CHAR( 38)
      LINTST(588) = CHAR( 42)
      LINTST(589) = CHAR( 40)
      LINTST(590) = CHAR( 42)
      LINTST(591) = CHAR( 40)
      LINTST(592) = CHAR( 40)
      LINTST(593) = CHAR( 40)
      LINTST(594) = CHAR( 40)
      LINTST(595) = CHAR( 38)
      LINTST(596) = CHAR( 40)
      LINTST(597) = CHAR( 38)
      LINTST(598) = CHAR( 40)
      LINTST(599) = CHAR( 38)
      LINTST(600) = CHAR( 40)
      LINTST(601) = CHAR( 40)
      LINTST(602) = CHAR( 40)
      LINTST(603) = CHAR( 40)
      LINTST(604) = CHAR( 38)
      LINTST(605) = CHAR( 40)
      LINTST(606) = CHAR( 40)
      LINTST(607) = CHAR( 40)
      LINTST(608) = CHAR( 40)
      LINTST(609) = CHAR( 38)
      LINTST(610) = CHAR( 40)
      LINTST(611) = CHAR( 40)
      LINTST(612) = CHAR( 40)
      LINTST(613) = CHAR( 40)
      LINTST(614) = CHAR( 42)
      LINTST(615) = CHAR( 40)
      LINTST(616) = CHAR( 42)
      LINTST(617) = CHAR( 40)
      LINTST(618) = CHAR( 42)
      LINTST(619) = CHAR( 40)
      LINTST(620) = CHAR( 38)
      LINTST(621) = CHAR( 40)
      LINTST(622) = CHAR( 40)
      LINTST(623) = CHAR( 40)
      LINTST(624) = CHAR( 38)
      LINTST(625) = CHAR( 40)
      LINTST(626) = CHAR( 42)
      LINTST(627) = CHAR( 40)
      LINTST(628) = CHAR( 40)
      LINTST(629) = CHAR( 40)
      LINTST(630) = CHAR( 40)
      LINTST(631) = CHAR( 40)
      LINTST(632) = CHAR( 38)
      LINTST(633) = CHAR( 40)
      LINTST(634) = CHAR( 40)
      LINTST(635) = CHAR( 38)
      LINTST(636) = CHAR( 48)
      LINTST(637) = CHAR( 46)
      LINTST(638) = CHAR( 38)
      LINTST(639) = CHAR( 40)
      LINTST(640) = CHAR( 40)
      LINTST(641) = CHAR( 40)
      LINTST(642) = CHAR( 38)
      LINTST(643) = CHAR( 38)
      LINTST(644) = CHAR(  0)
      LINTST(645) = CHAR(  0)
      LINTST(646) = CHAR(  0)
      LINTST(647) = CHAR(  0)
      LINTST(648) = CHAR(  0)
      LINTST(649) = CHAR(  0)
      LINTST(650) = CHAR(  0)
      LINTST(651) = CHAR(  0)
      LINTST(652) = CHAR(  0)
      LINTST(653) = CHAR(  0)
      LINTST(654) = CHAR(  0)
      LINTST(655) = CHAR(  0)
      LINTST(656) = CHAR(  0)
      LINTST(657) = CHAR(  0)
      LINTST(658) = CHAR(  0)
      LINTST(659) = CHAR(  0)
      LINTST(660) = CHAR(  0)
      LINTST(661) = CHAR(  0)
      LINTST(662) = CHAR(  0)
      LINTST(663) = CHAR(  0)
      LINTST(664) = CHAR(  0)
      LINTST(665) = CHAR(  0)
      LINTST(666) = CHAR(  0)
      LINTST(667) = CHAR(  0)
      LINTST(668) = CHAR(  0)
      LINTST(669) = CHAR(  0)
      LINTST(670) = CHAR(  0)
      LINTST(671) = CHAR(  0)
      LINTST(672) = CHAR(  0)
      LINTST(673) = CHAR(  0)
      LINTST(674) = CHAR(  0)
      LINTST(675) = CHAR(  0)
      LINTST(676) = CHAR(  0)
      LINTST(677) = CHAR(  0)
      LINTST(678) = CHAR(  0)
      LINTST(679) = CHAR(  0)
      LINTST(680) = CHAR(  0)
      LINTST(681) = CHAR(  0)
      LINTST(682) = CHAR(  0)
      LINTST(683) = CHAR(  0)
      LINTST(684) = CHAR(  0)
      LINTST(685) = CHAR(  0)
      LINTST(686) = CHAR(  0)
      LINTST(687) = CHAR(  0)
      LINTST(688) = CHAR(  0)
      LINTST(689) = CHAR(  0)
      LINTST(690) = CHAR(  0)
      LINTST(691) = CHAR(  0)
      LINTST(692) = CHAR(  0)
      LINTST(693) = CHAR(  0)
      LINTST(694) = CHAR(  0)
      LINTST(695) = CHAR(  0)
      LINTST(696) = CHAR(  0)
      LINTST(697) = CHAR(  0)
      LINTST(698) = CHAR(  0)
      LINTST(699) = CHAR(  0)
      LINTST(700) = CHAR(  0)
      LINTST(701) = CHAR(  0)
      LINTST(702) = CHAR(  0)
      LINTST(703) = CHAR(  0)
      LINTST(704) = CHAR(  0)
      LINTST(705) = CHAR(  0)
      LINTST(706) = CHAR(  0)
      LINTST(707) = CHAR(  0)
      LINTST(708) = CHAR(  0)
      LINTST(709) = CHAR(  0)
      LINTST(710) = CHAR(  0)
      LINTST(711) = CHAR(  0)
      LINTST(712) = CHAR(  0)
      LINTST(713) = CHAR(  0)
      LINTST(714) = CHAR(  0)
      LINTST(715) = CHAR(  0)
      LINTST(716) = CHAR(  0)
      LINTST(717) = CHAR(  0)
      LINTST(718) = CHAR(  0)
      LINTST(719) = CHAR(  0)
      LINTST(720) = CHAR(  0)
      LINTST(721) = CHAR(  0)
      LINTST(722) = CHAR(  0)
      LINTST(723) = CHAR(  0)
      LINTST(724) = CHAR(  0)
      LINTST(725) = CHAR(  0)
      LINTST(726) = CHAR(  0)
      LINTST(727) = CHAR(  0)
      LINTST(728) = CHAR(  0)
      LINTST(729) = CHAR(  0)
      LINTST(730) = CHAR(  0)
      LINTST(731) = CHAR(  0)
      LINTST(732) = CHAR(  0)
      LINTST(733) = CHAR(  0)
      LINTST(734) = CHAR(  0)
      LINTST(735) = CHAR(  0)
      LINTST(736) = CHAR(  0)
      LINTST(737) = CHAR(  0)
      LINTST(738) = CHAR(  0)
      LINTST(739) = CHAR(  0)
      LINTST(740) = CHAR(  0)
      LINTST(741) = CHAR(  0)
      LINTST(742) = CHAR(  0)
      LINTST(743) = CHAR(  0)
      LINTST(744) = CHAR(  0)
      LINTST(745) = CHAR(  0)
      LINTST(746) = CHAR(  0)
      LINTST(747) = CHAR(  0)
      LINTST(748) = CHAR(  0)
      LINTST(749) = CHAR(  0)
      LINTST(750) = CHAR(  0)
      LINTST(751) = CHAR(  0)
      LINTST(752) = CHAR(  0)
      LINTST(753) = CHAR(  0)
      LINTST(754) = CHAR(  0)
      LINTST(755) = CHAR(  0)
      LINTST(756) = CHAR(  0)
      LINTST(757) = CHAR(  0)
      LINTST(758) = CHAR(  0)
      LINTST(759) = CHAR(  0)
      LINTST(760) = CHAR(  0)
      LINTST(761) = CHAR(  0)
      LINTST(762) = CHAR(  0)
      LINTST(763) = CHAR(  0)
      LINTST(764) = CHAR(  0)
      LINTST(765) = CHAR(  0)
      LINTST(766) = CHAR(  0)
      LINTST(767) = CHAR(  0)
      LINTST(768) = CHAR(  0)
      LINTST(769) = CHAR(  0)
      LINTST(770) = CHAR(  0)
      LINTST(771) = CHAR(  0)
      LINTST(772) = CHAR(  0)
      LINTST(773) = CHAR(  0)
      LINTST(774) = CHAR(  0)
      LINTST(775) = CHAR(  0)
      LINTST(776) = CHAR(  0)
      LINTST(777) = CHAR(  0)
      LINTST(778) = CHAR(  0)
      LINTST(779) = CHAR(  0)
      LINTST(780) = CHAR(  0)
      LINTST(781) = CHAR(  0)
      LINTST(782) = CHAR(  0)
      LINTST(783) = CHAR(  0)
      LINTST(784) = CHAR(  0)
      LINTST(785) = CHAR(  0)
      LINTST(786) = CHAR(  0)
      LINTST(787) = CHAR(  0)
      LINTST(788) = CHAR(  0)
      LINTST(789) = CHAR(  0)
      LINTST(790) = CHAR(  0)
      LINTST(791) = CHAR(  0)
      LINTST(792) = CHAR(  0)
      LINTST(793) = CHAR(  0)
      LINTST(794) = CHAR(  0)
      LINTST(795) = CHAR(  0)
      LINTST(796) = CHAR(  0)
      LINTST(797) = CHAR(  0)
      LINTST(798) = CHAR(  0)
      LINTST(799) = CHAR(  0)
      LINTST(800) = CHAR(  0)
      LINTST(801) = CHAR(179)
      LINTST(802) = CHAR(104)
      LINTST(803) = CHAR(  2)
      LINTST(804) = CHAR(  0)
      LINTST(805) = CHAR(  1)
      LINTST(806) = CHAR(  0)
      LINTST(807) = CHAR(  1)
      LINTST(808) = CHAR(  0)
      LINTST(809) = CHAR(  0)
      LINTST(810) = CHAR(  0)
      LINTST(811) = CHAR( 24)
      LINTST(812) = CHAR( 20)
      LINTST(813) = CHAR(  0)
      LINTST(814) = CHAR(  0)
      LINTST(815) = CHAR(  0)
      LINTST(816) = CHAR(  0)
      LINTST(817) = CHAR(  0)
      LINTST(818) = CHAR(  0)
      LINTST(819) = CHAR(  0)
      LINTST(820) = CHAR(  0)
      LINTST(821) = CHAR(  0)
      LINTST(822) = CHAR(  0)
      LINTST(823) = CHAR(  0)
      LINTST(824) = CHAR(  0)
      LINTST(825) = CHAR(  0)
      LINTST(826) = CHAR(  0)
      LINTST(827) = CHAR(  0)
      LINTST(828) = CHAR(  0)
      LINTST(829) = CHAR(  0)
      LINTST(830) = CHAR(  0)
      LINTST(831) = CHAR(  0)
      LINTST(832) = CHAR(  2)
      LINTST(833) = CHAR(  1)
      LINTST(834) = CHAR(  0)
      LINTST(835) = CHAR(131)
      LINTST(836) = CHAR(  2)
C****************************************************************************
C Work begins here. Initialize the Huffman coding tree with call to
C DECMPINIT. Decompress the compressed line contained in LININ.
C Output of decompression ends up in LINOUT
C***************************************************************************
      CALL DECMPINIT(HIST)
      IFAIL = 0
      DO 200 J = 1,2
      CALL DECOMPRESS(LININ,LINOUT,LENIN,LENOUT)
C****************************************************************************
C Compare decompressed line in LINOUT with values in LINTST.
C Report any errors if there are any mismatches. If mismatches exist
C the decompression routines have not been successfully implemented on
C your computer system.
C****************************************************************************
      DO 100 I = 1,LENOUT
      IF (LINOUT(I).NE.LINTST(I)) THEN
      IFAIL = 1
      IOUT = ICHAR(LINOUT(I))
      ITEST= ICHAR(LINTST(I))
      WRITE(IP,900) I,IOUT,ITEST
  900 FORMAT(' Error, decompression failed '/,
     .'   Sample number:',i3,
     .'   Value coming out of DECOMPRESS routine: ',i4,/,
     .'   Value should be: ',i4)
      END IF
  100 CONTINUE
  200 CONTINUE
      IF (IFAIL.EQ.0) WRITE(IP,905)
  905 FORMAT(' Decompression subroutines were successful')
      IF (IFAIL.NE.0) WRITE(IP,910)
  910 FORMAT(' Decompression subroutines failed')
      STOP
      END
